package com.ruoyi.bst.complaint.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.complaint.mapper.ComplaintMapper;
import com.ruoyi.bst.complaint.domain.Complaint;
import com.ruoyi.bst.complaint.domain.ComplaintVO;
import com.ruoyi.bst.complaint.domain.ComplaintQuery;
import com.ruoyi.bst.complaint.service.ComplaintService;

/**
 * 投诉列表Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-22
 */
@Service
public class ComplaintServiceImpl implements ComplaintService
{
    @Autowired
    private ComplaintMapper complaintMapper;

    /**
     * 查询投诉列表
     *
     * @param id 投诉列表主键
     * @return 投诉列表
     */
    @Override
    public ComplaintVO selectComplaintById(Long id)
    {
        return complaintMapper.selectComplaintById(id);
    }

    /**
     * 查询投诉列表列表
     *
     * @param complaint 投诉列表
     * @return 投诉列表
     */
    @Override
    public List<ComplaintVO> selectComplaintList(ComplaintQuery complaint)
    {
        return complaintMapper.selectComplaintList(complaint);
    }

    /**
     * 新增投诉列表
     *
     * @param complaint 投诉列表
     * @return 结果
     */
    @Override
    public int insertComplaint(Complaint complaint)
    {
        complaint.setCreateTime(DateUtils.getNowDate());
        return complaintMapper.insertComplaint(complaint);
    }

    /**
     * 修改投诉列表
     *
     * @param complaint 投诉列表
     * @return 结果
     */
    @Override
    public int updateComplaint(Complaint complaint)
    {
        return complaintMapper.updateComplaint(complaint);
    }

    /**
     * 批量删除投诉列表
     *
     * @param ids 需要删除的投诉列表主键
     * @return 结果
     */
    @Override
    public int deleteComplaintByIds(Long[] ids)
    {
        return complaintMapper.deleteComplaintByIds(ids);
    }

    /**
     * 删除投诉列表信息
     *
     * @param id 投诉列表主键
     * @return 结果
     */
    @Override
    public int deleteComplaintById(Long id)
    {
        return complaintMapper.deleteComplaintById(id);
    }
}
